S4 class to represent coefficients of object pairs for the comparison of two object partitions (say \(P\) and \(Q\)).
N11The number of object pairs that are in both partitions together in a cluster
N00The number of object pairs that are in no partition together in a cluster
N10The number of object pairs that are only in partition \(P\) together in a cluster
N01The number of object pairs that are only in partition \(Q\) together in a cluster